# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector.api.fcm_api import FCMApi  # noqa: E501


class TestFCMApi(unittest.IsolatedAsyncioTestCase):
    """FCMApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = FCMApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_fcm_subscribe_to_fcm(self) -> None:
        """Test case for fcm_subscribe_to_fcm

        Subscribe to FCM  # noqa: E501
        """
        pass

    async def test_fcm_unsubscribe_from_fcm(self) -> None:
        """Test case for fcm_unsubscribe_from_fcm

        Unsubscribe from FCM  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
